@@ -23,6 +23,7 @@ from apis_core.apis_entities.serializers_generic import EntitySerializer
 from apis_core.apis_labels.models import Label
 from apis_core.apis_vocabularies.models import CollectionType, LabelType, TextType
 
+from django.contrib.contenttypes.fields import GenericRelation
 # from helper_functions.highlighter import highlight_text
 from apis_core.default_settings.NER_settings import autocomp_settings
 from apis_core.helper_functions import DateParser
@@ -30,10 +31,6 @@ from apis_core.helper_functions import DateParser
 NEXT_PREV = getattr(settings, "APIS_NEXT_PREV", True)
 
 
-if "apis_highlighter" in settings.INSTALLED_APPS:
-    from apis_highlighter.models import Annotation
-
-
 @reversion.register()
 class TempEntityClass(models.Model):
     """Base class to bind common attributes to many classes.
@@ -80,6 +77,10 @@ class TempEntityClass(models.Model):
     objects = models.Manager()
     objects_inheritance = InheritanceManager()
 
+    if "apis_highlighter" in settings.INSTALLED_APPS:
+        from apis_highlighter.models import Annotation
+        annotation_set = GenericRelation(Annotation)
+
     def __str__(self):
         if self.name != "" and hasattr(
             self, "first_name"
@@ -378,6 +379,8 @@ class Text(models.Model):
             return "ID: {}".format(self.id)
 
     def check_for_deleted_annotations(self):
+
+        from apis_highlighter.models import Annotation
         if self.pk is not None:
             deleted = []
             orig = Text.objects.get(pk=self.pk)
@@ -409,6 +412,7 @@ class Text(models.Model):
         if self.pk is not None:
             orig = Text.objects.get(pk=self.pk)
             if orig.text != self.text and "apis_highlighter" in settings.INSTALLED_APPS:
+                from apis_highlighter.models import Annotation
                 def calculate_context_weights(text, i_start, i_end):
 
                     def calculate_word_dict(text, direction):
